#!/bin/sh

#
# output temporary status file
#
clist_file="/var/tmp/.clist"
status_file="/var/tmp/.st_file"

# user config
. /etc/setup-netcfg/user.cfg

# board info
. /var/tmp/hwinfo

# software version
. /etc/scr1800-release

# wan info
case "$inet_if" in
ETH0)
	if_dev="eth0"
	;;
ETH1)
	if_dev="eth1"
	;;
ETH-USB)
	if_dev="usb1"
	;;
WLAN)
	if_dev="wlan0"
	;;
*)
	if_dev=""
	;;
esac

# at command def
at_cmd="sudo /usr/local/bin/at_cmd /dev/ttyACM0"

# check params
if [ -z "$lte_apn" ] || [ -z "$lte_user" ] || [ -z "$lte_password" ]; then
	lte_param_valid=0
else
	lte_param_valid=1
fi

if [ $inet_if = "LTE" ]; then
	$at_cmd 'AT+CGDCONT?' > /dev/null
	if [ $? -eq 0 ] && [ $lte_param_valid -eq 1 ]; then
		tmp=`$at_cmd AT+CGCONTRDP | grep 'CGCONTRDP' | awk '{print $2;}' | cut -d, -f4 | sed -e s/\"//g`
		wan_address=`echo $tmp | awk 'BEGIN {FS=".";OFS="."}{print $1,$2,$3,$4}'`
		wan_netmask=`echo $tmp | awk 'BEGIN {FS=".";OFS="."}{print $5,$6,$7,$8}'`
	fi
else
	wan_address=`/sbin/ifconfig $if_dev | grep 'inet addr' | awk '{print $2;}' | cut -d: -f2`
	wan_netmask=`/sbin/ifconfig $if_dev | grep 'inet addr' | awk '{print $4;}' | cut -d: -f2`
fi

if [ -z "$wan_address" ]; then
	wan_address="動作していません"
	wan_netmask="----"
fi


# lte rssi
if [ $inet_if = "LTE" ]; then
	tmp=`$at_cmd AT+CESQ | grep 'CESQ' | awk -F, '{print $6}' | sed -e "s/[\r\n]\+//g"`
	if [ -z "$tmp" ]; then
		lte_rssi="LTE 停止"
	elif [ $tmp -eq 255 ]; then
		lte_rssi="信号なし"
	elif [ $tmp -eq 97 ]; then
		lte_rssi=-44
	else
		lte_rssi=`expr $tmp - 141`
		lte_rssi="$lte_rssi dBm"
	fi

	tmp=`$at_cmd AT+CGACT?`
	echo $tmp | grep "4,1" > /dev/null
	if [ $? -ne 0 ]; then
		lte_rssi="LTE 停止"
	fi

else
	lte_rssi="LTE 停止"
fi


# wlan rssi
if [ $use_wifi = "1" ] && [ $wlan_mode = "STA" ]; then
	wlan_rssi=`/usr/sbin/iw dev wlan0 link | grep signal | awk '{print $2}'`
	wlan_rssi="$wlan_rssi dBm"
elif [ $use_wifi = "1" ] && [ $wlan_mode = "AP" ]; then
	wlan_rssi="WLAN APモード"
else
	wlan_rssi="WLAN 停止"
fi


# ddns/vpn info
tmp=`ps | grep ddclient | grep -v grep`
if [ -n "$tmp" ]; then
	ddns_status=$ddns_domain
else
	ddns_status="停止"
fi

tmp=`ps | grep openvpn | grep -v grep`
if [ -n "$tmp" ]; then
	vpn_status="動作中"
else
	vpn_status="停止"
fi


######################
# output to tempfile
######################
echo "wan_address=\"$wan_address\"" >  $status_file
echo "wan_netmask=\"$wan_netmask\"" >> $status_file

echo "lte_rssi=\"$lte_rssi\""       >> $status_file
echo "wlan_rssi=\"$wlan_rssi\""     >> $status_file

echo "ddns_status=\"$ddns_status\"" >> $status_file
echo "vpn_status=\"$vpn_status\""   >> $status_file


# lan clients
br0_net=${br0_address%%.*}
sudo /usr/bin/arp-scan -l -I br0 | grep "^$br0_net" > $clist_file

exit 0
